import React, { useCallback, memo } from "react";
import HeaderCell from "./HeaderCell";
import { assertIsValidKey } from "./utils";
import SuperHeaderCell from "./SuperHeaderCell";
function HeaderRow({ columns, superHeader, rows, rowKey, onSelectedRowsChange, allRowsSelected, onColumnResize, sortColumn, sortDirection, onSort, }) {
    const handleAllRowsSelectionChange = useCallback((checked) => {
        if (!onSelectedRowsChange)
            return;
        assertIsValidKey(rowKey);
        const newSelectedRows = new Set();
        if (checked) {
            for (const row of rows) {
                newSelectedRows.add(row[rowKey]);
            }
        }
        onSelectedRowsChange(newSelectedRows);
    }, [onSelectedRowsChange, rows, rowKey]);
    if (superHeader == undefined || superHeader.length == 0) {
        return (React.createElement("div", { role: "row", "aria-rowindex": 1, className: "rdg-header-row" }, columns.map((column) => {
            return (React.createElement(HeaderCell, { key: column.key, column: column, onResize: onColumnResize, allRowsSelected: allRowsSelected, onAllRowsSelectionChange: handleAllRowsSelectionChange, onSort: onSort, sortColumn: sortColumn, sortDirection: sortDirection }));
        })));
    }
    else {
        return (React.createElement("div", { role: "superHeaderWrapper", "aria-rowindex": 1 }, superHeader.map((header, i) => {
            var leftSum = 0; // this variable is only to get the sum of left for the positioning of the grid elements
            return (React.createElement("div", { role: "superHeader", "aria-rowindex": i + 1, className: "rdg-header-row" }, header.map((subHeader, i, arr) => {
                var left;
                if (i == 0) {
                    left = 0;
                }
                else if (i == 1) {
                    left = arr[i - 1].span * columns[0].width;
                }
                else {
                    left = arr[i - 1].span * columns[1].width;
                }
                if (i == 0) {
                    leftSum += left;
                    return (React.createElement(SuperHeaderCell, { key: subHeader.name, left: leftSum, column: columns[0], index: i, superSpecs: subHeader, onResize: onColumnResize, allRowsSelected: allRowsSelected, onAllRowsSelectionChange: handleAllRowsSelectionChange, onSort: onSort, sortColumn: sortColumn, sortDirection: sortDirection }));
                }
                else {
                    leftSum += left;
                    return (React.createElement(SuperHeaderCell, { key: subHeader.name, left: leftSum, column: columns[1], index: i, superSpecs: subHeader, onResize: onColumnResize, allRowsSelected: allRowsSelected, onAllRowsSelectionChange: handleAllRowsSelectionChange, onSort: onSort, sortColumn: sortColumn, sortDirection: sortDirection }));
                }
            })));
        })));
    }
}
export default memo(HeaderRow);
//# sourceMappingURL=HeaderRow.js.map